import React from 'react';

type Props = {
  layer: any;
  updatedLayer: any;
  graphInfo: any;
  deleteLayer: any;
};

export default function IconOptions({ layer, updatedLayer, graphInfo, deleteLayer }: Props) {
  const [categories, setCategories] = React.useState<string[]>([]);

  React.useEffect(() => {
    if (layer.config.attribute && graphInfo.nodeAttributes[layer.config.attribute]) {
      const attributeInfo = graphInfo.nodeAttributes[layer.config.attribute];
      if (attributeInfo && attributeInfo.values) {
        setCategories([...attributeInfo.values]);
      }
    }
  }, [layer.config.attribute, graphInfo.nodeAttributes]);

  return (
    <div>
      <div className="divider m-0"></div>

      <div>
        <select
          className="select select-bordered w-full max-w-xs"
          value={layer.config.attribute}
          onChange={(e) =>
            updatedLayer(layer.id, {
              config: {
                ...layer.config,
                attribute: e.target.value,
              },
            })
          }
        >
          <option disabled selected>
            Attribute
          </option>
          {Object.keys(graphInfo.nodeAttributes).map((type) => (
            <option key={type} value={type}>
              {type}
            </option>
          ))}
        </select>
        {categories && categories.map((cat) => <p key={cat}>{cat}</p>)}
      </div>

      <div className="divider m-0"></div>

      <div>
        <button
          className="btn btn-primary w-full"
          onClick={() =>
            updatedLayer(layer.id, {
              visible: !layer.visible,
            })
          }
        >
          {layer.visible ? 'Hide layer' : 'Show layer'}
        </button>

        <button className="btn btn-outline btn-primary w-full mt-1" onClick={() => deleteLayer(layer.id)}>
          Delete layer
        </button>
      </div>
    </div>
  );
}
